<?php

namespace Drupal\entity_theme_engine\Normalizer;


use Drupal\file\Entity\File;
use Drupal\system\Entity\Menu;
use Drupal\Core\Menu\MenuTreeParameters;

class EntityReferenceItemNormalizer extends FieldItemNormalizer {

  /**
   * The interface or class that this Normalizer supports.
   *
   * @var string
   */
  protected $supportedInterfaceOrClass = [
    'Drupal\Core\Field\Plugin\Field\FieldType\EntityReferenceItem',
  ];

  /**
   * {@inheritdoc}
   */
  public function normalize($field, $format = NULL, array $context = []) {
    $data = parent::normalize($field, $format, $context);
    $data['label'] = $field->entity->label();
    $data['url'] = $field->entity->toUrl()->toString();
    $data['uuid'] = $field->entity->uuid();
    try {
      $data['render'] = $this->entityTypeManager->getViewBuilder($field->entity->getEntityTypeId())->view($field->entity);
    } catch (\Exception $e) {
    }
    $field_definition = $context['field_definition'];
    $settings = $field_definition->getFieldStorageDefinition()->getSettings();
    if(!empty($settings['target_type'])) {
      $target_type = $settings['target_type'];
      switch ($target_type) {
        case 'media':
          if($field->entity->bundle() == 'image') {
            $target_id = $field->entity->getSource()->getSourceFieldValue($field->entity);
            $file = File::load($target_id);
            $data['styles'] = ImageItemNormalizer::getImageStylesVariables($file);
          }
          break;
        case 'image':
          $data['styles'] = ImageItemNormalizer::getImageStylesVariables($field->entity);
          break;
        case 'menu':
          $data['data'] = $this->getMenuData($field->entity);
          break;
      }
    }
    return $data;
  }

  public static function getMenuData(Menu $menu) {
    $parameters = new MenuTreeParameters();
    $parameters->onlyEnabledLinks();
    
    $menu_active_trail = \Drupal::service('menu.active_trail')->getActiveTrailIds($menu->id());
    $parameters->setActiveTrail($menu_active_trail);
    
    $links = \Drupal::menuTree()->load($menu->id(), $parameters);
    $data = static::processMenuLink($links);
    return $data;
  }
  
  protected static function processMenuLink($links) {
    if(empty($links)) return [];
    $data = [];
    foreach ($links as $key => $item) {
      $data[$key] = [
        'url' => $item->link->getUrlObject()->toString(),
        'title' => $item->link->getTitle(),
        'options' => $item->link->getOptions(),
        'active' => $item->inActiveTrail,
      ];
      if($item->hasChildren) {
        $data[$key]['subtree'] = static::processMenuLink($item->subtree);
      }
    }
    return $data;
  }
}
