<?php

namespace Drupal\entity_theme_engine\Normalizer;

use Drupal\Core\Field\FieldItemInterface;
use Drupal\serialization\Normalizer\ComplexDataNormalizer;
use Drupal\Core\Entity\EntityTypeManagerInterface;

/**
 * Denormalizes field item object structure by updating the entity field values.
 */
class FieldItemNormalizer extends ComplexDataNormalizer {

  /**
   * {@inheritdoc}
   */
  protected $supportedInterfaceOrClass = FieldItemInterface::class;
  
  /**
   * @var string[]
   */
  protected $format = ['twig_variable'];
  
  /**
   * @var \Drupal\Core\Entity\EntityTypeManagerInterface
   */
  protected $entityTypeManager;
  
  /**
   * @param \Drupal\Core\Entity\EntityTypeManagerInterface $entity_type_manager
   */
  public function __construct(EntityTypeManagerInterface $entity_type_manager) {
    $this->entityTypeManager = $entity_type_manager;
  }

  /**
   * {@inheritdoc}
   */
  public function supportsNormalization($data, $format = NULL) {
    if(in_array($format, $this->format) && parent::supportsNormalization($data, $format)) {
      return TRUE;
    }
    return FALSE;
  }
  /**
   * {@inheritdoc}
   */
  public function normalize($object, $format = NULL, array $context = []) {
    $data = $object->getValue();
    foreach ($data as $key => $value) {
      if($key[0] == '_'){
        unset($data[$key]);
      }
    }
    return $data;
  }
}
